# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Transaction(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'coins': 'Coins',
        'height': 'str',
        'tx_id': 'str'
    }

    attribute_map = {
        'address': 'address',
        'coins': 'coins',
        'height': 'height',
        'tx_id': 'txID'
    }

    def __init__(self, address=None, coins=None, height=None, tx_id=None):  # noqa: E501
        """Transaction - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._coins = None
        self._height = None
        self._tx_id = None
        self.discriminator = None
        self.address = address
        self.coins = coins
        if height is not None:
            self.height = height
        self.tx_id = tx_id

    @property
    def address(self):
        """Gets the address of this Transaction.  # noqa: E501

        Sender address  # noqa: E501

        :return: The address of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Transaction.

        Sender address  # noqa: E501

        :param address: The address of this Transaction.  # noqa: E501
        :type: str
        """
        if address is None:
            raise ValueError("Invalid value for `address`, must not be `None`")  # noqa: E501

        self._address = address

    @property
    def coins(self):
        """Gets the coins of this Transaction.  # noqa: E501


        :return: The coins of this Transaction.  # noqa: E501
        :rtype: Coins
        """
        return self._coins

    @coins.setter
    def coins(self, coins):
        """Sets the coins of this Transaction.


        :param coins: The coins of this Transaction.  # noqa: E501
        :type: Coins
        """
        if coins is None:
            raise ValueError("Invalid value for `coins`, must not be `None`")  # noqa: E501

        self._coins = coins

    @property
    def height(self):
        """Gets the height of this Transaction.  # noqa: E501

        The thorchain height that the outbound transaction occurred.   # noqa: E501

        :return: The height of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Transaction.

        The thorchain height that the outbound transaction occurred.   # noqa: E501

        :param height: The height of this Transaction.  # noqa: E501
        :type: str
        """

        self._height = height

    @property
    def tx_id(self):
        """Gets the tx_id of this Transaction.  # noqa: E501

        Transaction id hash. Some transactions (such as outbound transactions made in the native asset) may have a zero value.   # noqa: E501

        :return: The tx_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this Transaction.

        Transaction id hash. Some transactions (such as outbound transactions made in the native asset) may have a zero value.   # noqa: E501

        :param tx_id: The tx_id of this Transaction.  # noqa: E501
        :type: str
        """
        if tx_id is None:
            raise ValueError("Invalid value for `tx_id`, must not be `None`")  # noqa: E501

        self._tx_id = tx_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Transaction, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transaction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
