# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SaverPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_added': 'str',
        'asset_address': 'str',
        'asset_deposit': 'str',
        'asset_redeem': 'str',
        'asset_withdrawn': 'str',
        'date_first_added': 'str',
        'date_last_added': 'str',
        'pool': 'str',
        'saver_units': 'str'
    }

    attribute_map = {
        'asset_added': 'assetAdded',
        'asset_address': 'assetAddress',
        'asset_deposit': 'assetDeposit',
        'asset_redeem': 'assetRedeem',
        'asset_withdrawn': 'assetWithdrawn',
        'date_first_added': 'dateFirstAdded',
        'date_last_added': 'dateLastAdded',
        'pool': 'pool',
        'saver_units': 'saverUnits'
    }

    def __init__(self, asset_added=None, asset_address=None, asset_deposit=None, asset_redeem=None, asset_withdrawn=None, date_first_added=None, date_last_added=None, pool=None, saver_units=None):  # noqa: E501
        """SaverPool - a model defined in Swagger"""  # noqa: E501
        self._asset_added = None
        self._asset_address = None
        self._asset_deposit = None
        self._asset_redeem = None
        self._asset_withdrawn = None
        self._date_first_added = None
        self._date_last_added = None
        self._pool = None
        self._saver_units = None
        self.discriminator = None
        self.asset_added = asset_added
        self.asset_address = asset_address
        self.asset_deposit = asset_deposit
        self.asset_redeem = asset_redeem
        self.asset_withdrawn = asset_withdrawn
        self.date_first_added = date_first_added
        self.date_last_added = date_last_added
        self.pool = pool
        self.saver_units = saver_units

    @property
    def asset_added(self):
        """Gets the asset_added of this SaverPool.  # noqa: E501

        Int64(e8), total asset added in the saver pool by member  # noqa: E501

        :return: The asset_added of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_added

    @asset_added.setter
    def asset_added(self, asset_added):
        """Sets the asset_added of this SaverPool.

        Int64(e8), total asset added in the saver pool by member  # noqa: E501

        :param asset_added: The asset_added of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_added is None:
            raise ValueError("Invalid value for `asset_added`, must not be `None`")  # noqa: E501

        self._asset_added = asset_added

    @property
    def asset_address(self):
        """Gets the asset_address of this SaverPool.  # noqa: E501

        saver address used by the member  # noqa: E501

        :return: The asset_address of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_address

    @asset_address.setter
    def asset_address(self, asset_address):
        """Sets the asset_address of this SaverPool.

        saver address used by the member  # noqa: E501

        :param asset_address: The asset_address of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_address is None:
            raise ValueError("Invalid value for `asset_address`, must not be `None`")  # noqa: E501

        self._asset_address = asset_address

    @property
    def asset_deposit(self):
        """Gets the asset_deposit of this SaverPool.  # noqa: E501

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :return: The asset_deposit of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_deposit

    @asset_deposit.setter
    def asset_deposit(self, asset_deposit):
        """Sets the asset_deposit of this SaverPool.

        Int64(e8), total asset that is currently deposited by the member  # noqa: E501

        :param asset_deposit: The asset_deposit of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_deposit is None:
            raise ValueError("Invalid value for `asset_deposit`, must not be `None`")  # noqa: E501

        self._asset_deposit = asset_deposit

    @property
    def asset_redeem(self):
        """Gets the asset_redeem of this SaverPool.  # noqa: E501

        Int64(e8), total asset can be redeemed from the saver pool by member  # noqa: E501

        :return: The asset_redeem of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_redeem

    @asset_redeem.setter
    def asset_redeem(self, asset_redeem):
        """Sets the asset_redeem of this SaverPool.

        Int64(e8), total asset can be redeemed from the saver pool by member  # noqa: E501

        :param asset_redeem: The asset_redeem of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_redeem is None:
            raise ValueError("Invalid value for `asset_redeem`, must not be `None`")  # noqa: E501

        self._asset_redeem = asset_redeem

    @property
    def asset_withdrawn(self):
        """Gets the asset_withdrawn of this SaverPool.  # noqa: E501

        Int64(e8), total asset withdrawn from the saver pool by member  # noqa: E501

        :return: The asset_withdrawn of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_withdrawn

    @asset_withdrawn.setter
    def asset_withdrawn(self, asset_withdrawn):
        """Sets the asset_withdrawn of this SaverPool.

        Int64(e8), total asset withdrawn from the saver pool by member  # noqa: E501

        :param asset_withdrawn: The asset_withdrawn of this SaverPool.  # noqa: E501
        :type: str
        """
        if asset_withdrawn is None:
            raise ValueError("Invalid value for `asset_withdrawn`, must not be `None`")  # noqa: E501

        self._asset_withdrawn = asset_withdrawn

    @property
    def date_first_added(self):
        """Gets the date_first_added of this SaverPool.  # noqa: E501

        Int64, Unix timestamp for the first time member deposited into the saver pool  # noqa: E501

        :return: The date_first_added of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._date_first_added

    @date_first_added.setter
    def date_first_added(self, date_first_added):
        """Sets the date_first_added of this SaverPool.

        Int64, Unix timestamp for the first time member deposited into the saver pool  # noqa: E501

        :param date_first_added: The date_first_added of this SaverPool.  # noqa: E501
        :type: str
        """
        if date_first_added is None:
            raise ValueError("Invalid value for `date_first_added`, must not be `None`")  # noqa: E501

        self._date_first_added = date_first_added

    @property
    def date_last_added(self):
        """Gets the date_last_added of this SaverPool.  # noqa: E501

        Int64, Unix timestamp for the last time member deposited into the saver pool  # noqa: E501

        :return: The date_last_added of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._date_last_added

    @date_last_added.setter
    def date_last_added(self, date_last_added):
        """Sets the date_last_added of this SaverPool.

        Int64, Unix timestamp for the last time member deposited into the saver pool  # noqa: E501

        :param date_last_added: The date_last_added of this SaverPool.  # noqa: E501
        :type: str
        """
        if date_last_added is None:
            raise ValueError("Invalid value for `date_last_added`, must not be `None`")  # noqa: E501

        self._date_last_added = date_last_added

    @property
    def pool(self):
        """Gets the pool of this SaverPool.  # noqa: E501

        The Pool rest of the data are refering to (only those pools can show up which have a corresponding saver pool)  # noqa: E501

        :return: The pool of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """Sets the pool of this SaverPool.

        The Pool rest of the data are refering to (only those pools can show up which have a corresponding saver pool)  # noqa: E501

        :param pool: The pool of this SaverPool.  # noqa: E501
        :type: str
        """
        if pool is None:
            raise ValueError("Invalid value for `pool`, must not be `None`")  # noqa: E501

        self._pool = pool

    @property
    def saver_units(self):
        """Gets the saver_units of this SaverPool.  # noqa: E501

        Int64, saver liquidity units that belong the the member  # noqa: E501

        :return: The saver_units of this SaverPool.  # noqa: E501
        :rtype: str
        """
        return self._saver_units

    @saver_units.setter
    def saver_units(self, saver_units):
        """Sets the saver_units of this SaverPool.

        Int64, saver liquidity units that belong the the member  # noqa: E501

        :param saver_units: The saver_units of this SaverPool.  # noqa: E501
        :type: str
        """
        if saver_units is None:
            raise ValueError("Invalid value for `saver_units`, must not be `None`")  # noqa: E501

        self._saver_units = saver_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SaverPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaverPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
