# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_midgard
from xchainpy2_midgard.api.default_api import DefaultApi  # noqa: E501
from xchainpy2_midgard.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_actions(self):
        """Test case for get_actions

        Actions List  # noqa: E501
        """
        pass

    def test_get_balance(self):
        """Test case for get_balance

        Current balance for an address  # noqa: E501
        """
        pass

    def test_get_borrower_detail(self):
        """Test case for get_borrower_detail

        Borrower Details  # noqa: E501
        """
        pass

    def test_get_borrowers_addresses(self):
        """Test case for get_borrowers_addresses

        Borrowers List  # noqa: E501
        """
        pass

    def test_get_churns(self):
        """Test case for get_churns

        Churns List  # noqa: E501
        """
        pass

    def test_get_depth_history(self):
        """Test case for get_depth_history

        Depth and Price History  # noqa: E501
        """
        pass

    def test_get_earnings_history(self):
        """Test case for get_earnings_history

        Earnings History  # noqa: E501
        """
        pass

    def test_get_health(self):
        """Test case for get_health

        Health Info  # noqa: E501
        """
        pass

    def test_get_known_pools(self):
        """Test case for get_known_pools

        Known Pools List  # noqa: E501
        """
        pass

    def test_get_liquidity_history(self):
        """Test case for get_liquidity_history

        Liquidity Changes History  # noqa: E501
        """
        pass

    def test_get_member_detail(self):
        """Test case for get_member_detail

        Member Details  # noqa: E501
        """
        pass

    def test_get_members_adresses(self):
        """Test case for get_members_adresses

        Members List  # noqa: E501
        """
        pass

    def test_get_network_data(self):
        """Test case for get_network_data

        Network Data  # noqa: E501
        """
        pass

    def test_get_nodes(self):
        """Test case for get_nodes

        Nodes List  # noqa: E501
        """
        pass

    def test_get_pool(self):
        """Test case for get_pool

        Details of a Pool  # noqa: E501
        """
        pass

    def test_get_pool_stats(self):
        """Test case for get_pool_stats

        Pool Statistics  # noqa: E501
        """
        pass

    def test_get_pools(self):
        """Test case for get_pools

        Pools List  # noqa: E501
        """
        pass

    def test_get_saver_detail(self):
        """Test case for get_saver_detail

        Saver Details  # noqa: E501
        """
        pass

    def test_get_savers_history(self):
        """Test case for get_savers_history

        Savers Units and Depth History  # noqa: E501
        """
        pass

    def test_get_stats(self):
        """Test case for get_stats

        Global Stats  # noqa: E501
        """
        pass

    def test_get_swap_history(self):
        """Test case for get_swap_history

        Swaps History  # noqa: E501
        """
        pass

    def test_get_thor_name_detail(self):
        """Test case for get_thor_name_detail

        THORName Details  # noqa: E501
        """
        pass

    def test_get_thor_names_by_address(self):
        """Test case for get_thor_names_by_address

        Gives a list of THORNames by reverse lookup  # noqa: E501
        """
        pass

    def test_get_thor_names_owner_by_address(self):
        """Test case for get_thor_names_owner_by_address

        THORName owner  # noqa: E501
        """
        pass

    def test_get_tvl_history(self):
        """Test case for get_tvl_history

        Total Value Locked History  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
